@@ -34,6 +34,7 @@
 #include "Enumeration.h"
 #include "ScrollState.h"
 #include "Profile.h"
+#include "TerminalHeaderBar.h"
 
 class QDrag;
 class QDragEnterEvent;
@@ -73,6 +74,9 @@ public:
     explicit TerminalDisplay(QWidget *parent = nullptr);
     ~TerminalDisplay() Q_DECL_OVERRIDE;
 
+    void showDragTarget();
+    void hideDragTarget();
+
     void applyProfile(const Profile::Ptr& profile);
 
     /** Returns the terminal color palette used by the display. */
@@ -112,7 +116,6 @@ public:
 
     void setScrollFullPage(bool fullPage);
     bool scrollFullPage() const;
-
     /**
      * Returns the display's filter chain.  When the image for the display is updated,
      * the text is passed through each filter in the chain.  Each filter can define
@@ -293,6 +296,10 @@ public:
         return font();
     }
 
+    TerminalHeaderBar *headerBar() const
+    {
+        return _headerBar;
+    }
     /**
      * Sets the font used to draw the display.  Has no effect if @p font
      * is larger than the size of the display itself.
@@ -479,11 +486,15 @@ public Q_SLOTS:
         return _scrollbarLocation;
     }
 
+    Qt::Edge droppedEdge() const {
+        return _overlayEdge;
+    }
+
     // Used to show/hide the message widget
     void updateReadOnlyState(bool readonly);
     IncrementalSearchBar *searchBar() const;
 Q_SIGNALS:
-
+    void requestToggleExpansion();
     /**
      * Emitted when the user presses a key whilst the terminal widget has focus.
      */
@@ -591,13 +602,6 @@ private Q_SLOTS:
     void swapFGBGColors();
     void viewScrolledByUser();
 
-    /**
-     * Called from the drag-and-drop popup. Causes the dropped URLs to be pasted as text.
-     */
-    void dropMenuPasteActionTriggered();
-
-    void dropMenuCdActionTriggered();
-
     void dismissOutputSuspendedMessage();
 
 private:
@@ -852,9 +856,12 @@ private:
 
     ScrollState _scrollWheelState;
     IncrementalSearchBar *_searchBar;
-
+    TerminalHeaderBar *_headerBar;
     QRect _searchResultRect;
     friend class TerminalDisplayAccessible;
+
+    bool _drawOverlay;
+    Qt::Edge _overlayEdge;
 };
 
 class AutoScrollHandler : public QObject
