@@ -26,9 +26,17 @@ using namespace Konsole;
 TabBarSettings::TabBarSettings(QWidget* aParent) : QWidget(aParent)
 {
     setupUi(this);
+
+    // Enable CSS file selector only when tabbar is visible and custom css is active
+    const auto updateStyleSheetFileEnable = [this](bool) {
+        kcfg_TabBarUserStyleSheetFile->setEnabled(kcfg_TabBarUseUserStyleSheet->isChecked()
+                                                  && !AlwaysHideTabBar->isChecked());
+    };
+    connect(kcfg_TabBarUseUserStyleSheet, &QAbstractButton::toggled,
+            this, updateStyleSheetFileEnable);
+    connect(AlwaysHideTabBar, &QAbstractButton::toggled,
+            this, updateStyleSheetFileEnable);
 }
 
-TabBarSettings::~TabBarSettings()
-{
-}
+TabBarSettings::~TabBarSettings() = default;
 
